# automatically imports the bindings file into steamvr so you don't have to
# go through the awful UI yourself.
# This uses the undocumented API in the bindings UI itself (it's a webapp).
# SteamVR needs to be running for this to work, but avoids needing to mess with steamvr's json
# config directly.
Write-Host "Checking if SteamVR is running..."
# Check if SteamVR is running
$steamVRProcess = Get-Process -Name "vrcompositor" -ErrorAction SilentlyContinue
if (-not $steamVRProcess) {
    $wshell = New-Object -ComObject Wscript.Shell
    $wshell.Popup("SteamVR is not running. Please start SteamVR and try again.", 0, "SteamVR Not Running", 0x0 + 0x30)
    $null = $Host.UI.RawUI.ReadKey("NoEcho,IncludeKeyDown")
    exit 1
}

Write-Host "Copying bindings file..."
# Get the directory that the script is in
$currentDir = Split-Path -Parent $MyInvocation.MyCommand.Definition

# Source bindings file
$sourceBindingsFile = Join-Path -Path $currentDir -ChildPath "org.jrbudda.vivecraft.steamvrinput_knuckles.json"

# Ensure the source file exists
if (-not (Test-Path $sourceBindingsFile)) {
    Write-Error "Bindings file not found: $sourceBindingsFile"
    $null = $Host.UI.RawUI.ReadKey("NoEcho,IncludeKeyDown")
    exit 1
}

# Construct the path to the SteamVR input import directory
$steamVRImportDir = Join-Path -Path ([Environment]::GetFolderPath("MyDocuments")) -ChildPath "steamvr\input\imports"

# Ensure the SteamVR input import directory exists
if (-not (Test-Path $steamVRImportDir)) {
    New-Item -ItemType Directory -Path $steamVRImportDir -Force
}

# Destination path for the bindings file
$destBindingsFile = Join-Path -Path $steamVRImportDir -ChildPath "org.jrbudda.vivecraft.steamvrinput_knuckles.json"

# Copy the bindings file
Copy-Item -Path $sourceBindingsFile -Destination $destBindingsFile -Force

Write-Host "Calling SteamVR API..."
# Convert the destination file path to a file URI
$fileUri = [System.Uri]::new($destBindingsFile).AbsoluteUri

# Construct the body with the correct file URI
$body = @{
    app_key         = "org.jrbudda.vivecraft.steamvrinput"
    controller_type = "knuckles"
    url             = $fileUri
} | ConvertTo-Json

try {
    $response = Invoke-WebRequest -UseBasicParsing -Uri "http://localhost:27062/input/selectconfig.action" `
        -Method POST `
        -Headers @{
        "Accept"  = "application/json, text/plain, */*"
        "Origin"  = "http://localhost:27062"
        "Referer" = "http://localhost:27062/dashboard/controllerbinding.html"
    } `
        -ContentType "application/json" `
        -Body $body

    if ($response.StatusCode -eq 200) {
        $wshell = New-Object -ComObject Wscript.Shell
        $wshell.Popup("Sucessfully set recommended SteamVR bindings for Vivecraft.", 0, "Success", 0x0 + 0x40)
    }
}
catch {
    Write-Error "Failed to call the API: $_"
    $null = $Host.UI.RawUI.ReadKey("NoEcho,IncludeKeyDown")
    exit 1
}
